# Plotting `pl`

Visualization functions for seqlet analysis and motif exploration.

```{eval-rst}
.. module:: tfmindi.pl
.. currentmodule:: tfmindi

.. autosummary::
    :toctree: ../generated

    pl.tsne
    pl.tsne_logos
    pl.dbd_heatmap
    pl.dbd_topic_heatmap
    pl.region_contributions
    pl.dbd_logos
    pl.dbd_cluster_logos
    pl.region_topic_tsne
    pl.render_plot
```
